# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'

Puppet::Type.newtype(:wls_java_home) do
  include EasyType

  desc <<-DESC
  Ensure correct java home is present in WebLogic files in specified weblogic home.
  DESC

  def self.domain_file
    '/etc/wls_domains.dat'
  end

  to_get_raw_resources do
    return [] unless File.exist?(domain_file)

    file = File.read(domain_file)
    file.split.map do |domain|
      home = domain.split(':')[1]
      java_home = java_home_for(home)
      { :name => home, :java_home => java_home }
    end
  end

  def self.java_home_for(home)
    content = File.read("#{home}/bin/setDomainEnv.sh")
    content.scan(/JAVA_HOME="(.+)"/)[0][0]
  end

  def replace_java_home(file)
    file_name = "#{name}/#{file}"
    if File.exist?(file_name)
      Puppet.debug "Changing java_home in #{file_name} from: '#{provider.java_home}' to: '#{java_home}'"
      content = File.read(file_name)
      content.gsub!(provider.java_home, java_home)
      File.write(file_name, content)
    else
      Puppet.debug "Skipping change of java_home in #{file_name}, because file not found."
    end
  end

  on_modify do
    # Nodemanager
    replace_java_home('/nodemanager/nodemanager.properties')
    # bin
    replace_java_home('/bin/setNMJavaHome.sh')
    replace_java_home('/bin/setDomainEnv.sh')
    # init-info
    replace_java_home('/init-info/domain-info.xml')
    replace_java_home('/init-info/startscript.xml')
    replace_java_home('/init-info/tokenValue.properties')
    replace_java_home('/init-info/nodemanager-properties.xml')
    # config
    replace_java_home('/config/config.xml')
    replace_java_home('/config/config_bootstrap.xml')
    # rest
    replace_java_home('/backup_config/backup_config.xml')
    replace_java_home('//servers/domain_bak/config_prev/config.xml')
  end

  parameter :name
  property :java_home
end
